==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/UserDefinedFiveFieldSet.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR01" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR02" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR03" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR04" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR05" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFNUM01" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFNUM02" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFNUM03" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFNUM04" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFNUM05" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFDATE01" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFDATE02" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFDATE03" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFDATE04" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFDATE05" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX01" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX02" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX03" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX04" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX05" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "udfchar01",
    "udfchar02",
    "udfchar03",
    "udfchar04",
    "udfchar05",
    "udfnum01",
    "udfnum02",
    "udfnum03",
    "udfnum04",
    "udfnum05",
    "udfdate01",
    "udfdate02",
    "udfdate03",
    "udfdate04",
    "udfdate05",
    "udfchkbox01",
    "udfchkbox02",
    "udfchkbox03",
    "udfchkbox04",
    "udfchkbox05"
})
@XmlRootElement(name = "UserDefinedFiveFieldSet")
public class UserDefinedFiveFieldSet {

    @XmlElement(name = "UDFCHAR01")
    protected String udfchar01;
    @XmlElement(name = "UDFCHAR02")
    protected String udfchar02;
    @XmlElement(name = "UDFCHAR03")
    protected String udfchar03;
    @XmlElement(name = "UDFCHAR04")
    protected String udfchar04;
    @XmlElement(name = "UDFCHAR05")
    protected String udfchar05;
    @XmlElement(name = "UDFNUM01")
    protected QUANTITY udfnum01;
    @XmlElement(name = "UDFNUM02")
    protected QUANTITY udfnum02;
    @XmlElement(name = "UDFNUM03")
    protected QUANTITY udfnum03;
    @XmlElement(name = "UDFNUM04")
    protected QUANTITY udfnum04;
    @XmlElement(name = "UDFNUM05")
    protected QUANTITY udfnum05;
    @XmlElement(name = "UDFDATE01")
    protected DATETIME udfdate01;
    @XmlElement(name = "UDFDATE02")
    protected DATETIME udfdate02;
    @XmlElement(name = "UDFDATE03")
    protected DATETIME udfdate03;
    @XmlElement(name = "UDFDATE04")
    protected DATETIME udfdate04;
    @XmlElement(name = "UDFDATE05")
    protected DATETIME udfdate05;
    @XmlElement(name = "UDFCHKBOX01")
    protected String udfchkbox01;
    @XmlElement(name = "UDFCHKBOX02")
    protected String udfchkbox02;
    @XmlElement(name = "UDFCHKBOX03")
    protected String udfchkbox03;
    @XmlElement(name = "UDFCHKBOX04")
    protected String udfchkbox04;
    @XmlElement(name = "UDFCHKBOX05")
    protected String udfchkbox05;

    /**
     * Gets the value of the udfchar01 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR01() {
        return udfchar01;
    }

    /**
     * Sets the value of the udfchar01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR01(String value) {
        this.udfchar01 = value;
    }

    /**
     * Gets the value of the udfchar02 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR02() {
        return udfchar02;
    }

    /**
     * Sets the value of the udfchar02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR02(String value) {
        this.udfchar02 = value;
    }

    /**
     * Gets the value of the udfchar03 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR03() {
        return udfchar03;
    }

    /**
     * Sets the value of the udfchar03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR03(String value) {
        this.udfchar03 = value;
    }

    /**
     * Gets the value of the udfchar04 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR04() {
        return udfchar04;
    }

    /**
     * Sets the value of the udfchar04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR04(String value) {
        this.udfchar04 = value;
    }

    /**
     * Gets the value of the udfchar05 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR05() {
        return udfchar05;
    }

    /**
     * Sets the value of the udfchar05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR05(String value) {
        this.udfchar05 = value;
    }

    /**
     * Gets the value of the udfnum01 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM01() {
        return udfnum01;
    }

    /**
     * Sets the value of the udfnum01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM01(QUANTITY value) {
        this.udfnum01 = value;
    }

    /**
     * Gets the value of the udfnum02 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM02() {
        return udfnum02;
    }

    /**
     * Sets the value of the udfnum02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM02(QUANTITY value) {
        this.udfnum02 = value;
    }

    /**
     * Gets the value of the udfnum03 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM03() {
        return udfnum03;
    }

    /**
     * Sets the value of the udfnum03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM03(QUANTITY value) {
        this.udfnum03 = value;
    }

    /**
     * Gets the value of the udfnum04 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM04() {
        return udfnum04;
    }

    /**
     * Sets the value of the udfnum04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM04(QUANTITY value) {
        this.udfnum04 = value;
    }

    /**
     * Gets the value of the udfnum05 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM05() {
        return udfnum05;
    }

    /**
     * Sets the value of the udfnum05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM05(QUANTITY value) {
        this.udfnum05 = value;
    }

    /**
     * Gets the value of the udfdate01 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE01() {
        return udfdate01;
    }

    /**
     * Sets the value of the udfdate01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE01(DATETIME value) {
        this.udfdate01 = value;
    }

    /**
     * Gets the value of the udfdate02 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE02() {
        return udfdate02;
    }

    /**
     * Sets the value of the udfdate02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE02(DATETIME value) {
        this.udfdate02 = value;
    }

    /**
     * Gets the value of the udfdate03 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE03() {
        return udfdate03;
    }

    /**
     * Sets the value of the udfdate03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE03(DATETIME value) {
        this.udfdate03 = value;
    }

    /**
     * Gets the value of the udfdate04 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE04() {
        return udfdate04;
    }

    /**
     * Sets the value of the udfdate04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE04(DATETIME value) {
        this.udfdate04 = value;
    }

    /**
     * Gets the value of the udfdate05 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE05() {
        return udfdate05;
    }

    /**
     * Sets the value of the udfdate05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE05(DATETIME value) {
        this.udfdate05 = value;
    }

    /**
     * Gets the value of the udfchkbox01 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX01() {
        return udfchkbox01;
    }

    /**
     * Sets the value of the udfchkbox01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX01(String value) {
        this.udfchkbox01 = value;
    }

    /**
     * Gets the value of the udfchkbox02 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX02() {
        return udfchkbox02;
    }

    /**
     * Sets the value of the udfchkbox02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX02(String value) {
        this.udfchkbox02 = value;
    }

    /**
     * Gets the value of the udfchkbox03 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX03() {
        return udfchkbox03;
    }

    /**
     * Sets the value of the udfchkbox03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX03(String value) {
        this.udfchkbox03 = value;
    }

    /**
     * Gets the value of the udfchkbox04 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX04() {
        return udfchkbox04;
    }

    /**
     * Sets the value of the udfchkbox04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX04(String value) {
        this.udfchkbox04 = value;
    }

    /**
     * Gets the value of the udfchkbox05 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX05() {
        return udfchkbox05;
    }

    /**
     * Sets the value of the udfchkbox05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX05(String value) {
        this.udfchkbox05 = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/UserDefinedFiveFieldSet.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR01" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR02" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR03" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR04" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHAR05" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFNUM01" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFNUM02" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFNUM03" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFNUM04" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFNUM05" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFDATE01" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFDATE02" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFDATE03" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFDATE04" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFDATE05" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX01" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX02" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX03" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX04" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UDFCHKBOX05" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "udfchar01",
    "udfchar02",
    "udfchar03",
    "udfchar04",
    "udfchar05",
    "udfnum01",
    "udfnum02",
    "udfnum03",
    "udfnum04",
    "udfnum05",
    "udfdate01",
    "udfdate02",
    "udfdate03",
    "udfdate04",
    "udfdate05",
    "udfchkbox01",
    "udfchkbox02",
    "udfchkbox03",
    "udfchkbox04",
    "udfchkbox05"
})
@XmlRootElement(name = "UserDefinedFiveFieldSet")
public class UserDefinedFiveFieldSet {

    @XmlElement(name = "UDFCHAR01")
    protected String udfchar01;
    @XmlElement(name = "UDFCHAR02")
    protected String udfchar02;
    @XmlElement(name = "UDFCHAR03")
    protected String udfchar03;
    @XmlElement(name = "UDFCHAR04")
    protected String udfchar04;
    @XmlElement(name = "UDFCHAR05")
    protected String udfchar05;
    @XmlElement(name = "UDFNUM01")
    protected QUANTITY udfnum01;
    @XmlElement(name = "UDFNUM02")
    protected QUANTITY udfnum02;
    @XmlElement(name = "UDFNUM03")
    protected QUANTITY udfnum03;
    @XmlElement(name = "UDFNUM04")
    protected QUANTITY udfnum04;
    @XmlElement(name = "UDFNUM05")
    protected QUANTITY udfnum05;
    @XmlElement(name = "UDFDATE01")
    protected DATETIME udfdate01;
    @XmlElement(name = "UDFDATE02")
    protected DATETIME udfdate02;
    @XmlElement(name = "UDFDATE03")
    protected DATETIME udfdate03;
    @XmlElement(name = "UDFDATE04")
    protected DATETIME udfdate04;
    @XmlElement(name = "UDFDATE05")
    protected DATETIME udfdate05;
    @XmlElement(name = "UDFCHKBOX01")
    protected String udfchkbox01;
    @XmlElement(name = "UDFCHKBOX02")
    protected String udfchkbox02;
    @XmlElement(name = "UDFCHKBOX03")
    protected String udfchkbox03;
    @XmlElement(name = "UDFCHKBOX04")
    protected String udfchkbox04;
    @XmlElement(name = "UDFCHKBOX05")
    protected String udfchkbox05;

    /**
     * Gets the value of the udfchar01 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR01() {
        return udfchar01;
    }

    /**
     * Sets the value of the udfchar01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR01(String value) {
        this.udfchar01 = value;
    }

    /**
     * Gets the value of the udfchar02 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR02() {
        return udfchar02;
    }

    /**
     * Sets the value of the udfchar02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR02(String value) {
        this.udfchar02 = value;
    }

    /**
     * Gets the value of the udfchar03 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR03() {
        return udfchar03;
    }

    /**
     * Sets the value of the udfchar03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR03(String value) {
        this.udfchar03 = value;
    }

    /**
     * Gets the value of the udfchar04 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR04() {
        return udfchar04;
    }

    /**
     * Sets the value of the udfchar04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR04(String value) {
        this.udfchar04 = value;
    }

    /**
     * Gets the value of the udfchar05 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHAR05() {
        return udfchar05;
    }

    /**
     * Sets the value of the udfchar05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHAR05(String value) {
        this.udfchar05 = value;
    }

    /**
     * Gets the value of the udfnum01 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM01() {
        return udfnum01;
    }

    /**
     * Sets the value of the udfnum01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM01(QUANTITY value) {
        this.udfnum01 = value;
    }

    /**
     * Gets the value of the udfnum02 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM02() {
        return udfnum02;
    }

    /**
     * Sets the value of the udfnum02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM02(QUANTITY value) {
        this.udfnum02 = value;
    }

    /**
     * Gets the value of the udfnum03 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM03() {
        return udfnum03;
    }

    /**
     * Sets the value of the udfnum03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM03(QUANTITY value) {
        this.udfnum03 = value;
    }

    /**
     * Gets the value of the udfnum04 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM04() {
        return udfnum04;
    }

    /**
     * Sets the value of the udfnum04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM04(QUANTITY value) {
        this.udfnum04 = value;
    }

    /**
     * Gets the value of the udfnum05 property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getUDFNUM05() {
        return udfnum05;
    }

    /**
     * Sets the value of the udfnum05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setUDFNUM05(QUANTITY value) {
        this.udfnum05 = value;
    }

    /**
     * Gets the value of the udfdate01 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE01() {
        return udfdate01;
    }

    /**
     * Sets the value of the udfdate01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE01(DATETIME value) {
        this.udfdate01 = value;
    }

    /**
     * Gets the value of the udfdate02 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE02() {
        return udfdate02;
    }

    /**
     * Sets the value of the udfdate02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE02(DATETIME value) {
        this.udfdate02 = value;
    }

    /**
     * Gets the value of the udfdate03 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE03() {
        return udfdate03;
    }

    /**
     * Sets the value of the udfdate03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE03(DATETIME value) {
        this.udfdate03 = value;
    }

    /**
     * Gets the value of the udfdate04 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE04() {
        return udfdate04;
    }

    /**
     * Sets the value of the udfdate04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE04(DATETIME value) {
        this.udfdate04 = value;
    }

    /**
     * Gets the value of the udfdate05 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUDFDATE05() {
        return udfdate05;
    }

    /**
     * Sets the value of the udfdate05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUDFDATE05(DATETIME value) {
        this.udfdate05 = value;
    }

    /**
     * Gets the value of the udfchkbox01 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX01() {
        return udfchkbox01;
    }

    /**
     * Sets the value of the udfchkbox01 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX01(String value) {
        this.udfchkbox01 = value;
    }

    /**
     * Gets the value of the udfchkbox02 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX02() {
        return udfchkbox02;
    }

    /**
     * Sets the value of the udfchkbox02 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX02(String value) {
        this.udfchkbox02 = value;
    }

    /**
     * Gets the value of the udfchkbox03 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX03() {
        return udfchkbox03;
    }

    /**
     * Sets the value of the udfchkbox03 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX03(String value) {
        this.udfchkbox03 = value;
    }

    /**
     * Gets the value of the udfchkbox04 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX04() {
        return udfchkbox04;
    }

    /**
     * Sets the value of the udfchkbox04 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX04(String value) {
        this.udfchkbox04 = value;
    }

    /**
     * Gets the value of the udfchkbox05 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUDFCHKBOX05() {
        return udfchkbox05;
    }

    /**
     * Sets the value of the udfchkbox05 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUDFCHKBOX05(String value) {
        this.udfchkbox05 = value;
    }

}
